pub enum SessionError {
Show 58 variants
SlimChannelClosed,
SlimReception(Status),
MessageError(MessageError),
MissingRemovedParticipantInGroupRemove,
MissingGroupNameInJoinRequest,
PingStateNotInitialized,
MissingChannelName,
SessionTypeUnknown(ProtoSessionType),
SessionMessageInternalUnexpected(Box<SessionMessage>),
SessionMessageTypeUnknown(ProtoSessionMessageType),
MessageTypeUnexpected(Box<ProtoMessage>),
SessionMessageTypeUnexpected(ProtoSessionMessageType),
ParticipantsListQueryFailed,
UnexpectedError {
source: Box<SessionError>,
},
SessionNotFound(u32),
SubscriptionNotFound(Name),
SessionBuilderIncomplete,
MessageLost(u32),
SessionClosed,
ReceiveTimeout,
SessionIdAlreadyUsed(u32),
InvalidSessionId(u32),
MlsOp(MlsError),
Auth(AuthError),
AckReception(String),
SubscriptionAckFailed(SubscriptionAckError),
UnknownDestination(Name),
ParticipantNotFound(Name),
ParticipantAlreadyInGroup(Name),
CannotInviteToP2P,
CannotRemoveFromP2P,
NotInitiator,
SessionControllerSendFailed,
NewSessionSendFailed,
SessionDeleteMessageSendFailed,
ApplicationMessageSendFailed,
SlimMessageSendFailed,
SlimSendFailure {
ctx: Box<ErrorPayload>,
},
SessionDrainingDrop,
SessionAlreadyClosed,
SessionCleanupFailed {
details: String,
},
MessageSendRetryFailed {
id: u32,
},
MessageReceiveRetryFailed {
id: u32,
},
SessionSenderShutdown,
MissingPayload {
context: &'static str,
},
MessageBuild(MessageError),
PayloadExtract {
context: &'static str,
source: MessageError,
},
WelcomeMessageMissingMlsPayload,
InvalidJoinRequestPayload,
ParticipantDisconnected(Name),
MissingParticipantNameOnDisconnection,
TimerNotFound(u32),
ModeratorTaskUnsupportedPhase,
ModeratorTaskUnexpectedTimerId(u32),
ModeratorTaskAddFailed {
source: Box<SessionError>,
},
ModeratorTaskRemoveFailed {
source: Box<SessionError>,
},
ModeratorTaskUpdateFailed {
source: Box<SessionError>,
},
ModeratorTaskCloseFailed {
source: Box<SessionError>,
},
}Variants
SlimChannelClosed
SlimReception(Status)
MessageError(MessageError)
MissingRemovedParticipantInGroupRemove
MissingGroupNameInJoinRequest
PingStateNotInitialized
MissingChannelName
SessionTypeUnknown(ProtoSessionType)
SessionMessageInternalUnexpected(Box<SessionMessage>)
SessionMessageTypeUnknown(ProtoSessionMessageType)
MessageTypeUnexpected(Box<ProtoMessage>)
SessionMessageTypeUnexpected(ProtoSessionMessageType)
ParticipantsListQueryFailed
UnexpectedError
Fields

source: Box<SessionError>SessionNotFound(u32)
SubscriptionNotFound(Name)
SessionBuilderIncomplete
MessageLost(u32)
SessionClosed
ReceiveTimeout
SessionIdAlreadyUsed(u32)
InvalidSessionId(u32)
MlsOp(MlsError)
Auth(AuthError)
AckReception(String)
SubscriptionAckFailed(SubscriptionAckError)
UnknownDestination(Name)
ParticipantNotFound(Name)
ParticipantAlreadyInGroup(Name)
CannotInviteToP2P
CannotRemoveFromP2P
NotInitiator
SessionControllerSendFailed
NewSessionSendFailed
SessionDeleteMessageSendFailed
ApplicationMessageSendFailed
SlimMessageSendFailed
SlimSendFailure
Fields

ctx: Box<ErrorPayload>SessionDrainingDrop
SessionAlreadyClosed
SessionCleanupFailed
MessageSendRetryFailed
MessageReceiveRetryFailed
SessionSenderShutdown
MissingPayload
MessageBuild(MessageError)
PayloadExtract
WelcomeMessageMissingMlsPayload
InvalidJoinRequestPayload
ParticipantDisconnected(Name)
MissingParticipantNameOnDisconnection
TimerNotFound(u32)
ModeratorTaskUnsupportedPhase
ModeratorTaskUnexpectedTimerId(u32)
ModeratorTaskAddFailed
Fields

source: Box<SessionError>ModeratorTaskRemoveFailed
Fields

source: Box<SessionError>ModeratorTaskUpdateFailed
Fields

source: Box<SessionError>ModeratorTaskCloseFailed
Fields

source: Box<SessionError>Implementations
Sourceimpl SessionError
impl SessionError
pub fn build_error(err: MessageError) -> Self
pub fn extract_error(context: &'static str, err: MessageError) -> Self
pub fn cleanup_failed<E: Display>(e: E) -> Self
pub fn send_retry_failed(id: u32) -> Self
pub fn receive_retry_failed(id: u32) -> Self
Sourcepub fn session_context(&self) -> Option<&MessageContext>
pub fn session_context(&self) -> Option<&MessageContext>
Extract session context from SlimSendFailure error Returns None if the error is not a SlimSendFailure or if it lacks session context
Sourcepub fn is_command_message_error(&self) -> bool
pub fn is_command_message_error(&self) -> bool
Check if this error is for a command message