pub struct TimerSettings {
pub duration: Duration,
pub max_duration: Option<Duration>,
pub max_retries: Option<u32>,
pub timer_type: TimerType,
}Fields
duration: Durationmax_duration: Option<Duration>max_retries: Option<u32>timer_type: TimerTypeImplementations
Sourceimpl TimerSettings
impl TimerSettings
Sourcepub fn new(
duration: Duration,
max_duration: Option<Duration>,
max_retries: Option<u32>,
timer_type: TimerType,
) -> Self
pub fn new( duration: Duration, max_duration: Option<Duration>, max_retries: Option<u32>, timer_type: TimerType, ) -> Self
Create a new TimerSettings with the specified parameters
Sourcepub fn constant(duration: Duration) -> Self
pub fn constant(duration: Duration) -> Self
Create a constant timer settings with the specified duration
Sourcepub fn exponential(
initial_duration: Duration,
max_duration: Option<Duration>,
) -> Self
pub fn exponential( initial_duration: Duration, max_duration: Option<Duration>, ) -> Self
Create an exponential timer settings with the specified duration and max duration
Sourcepub fn with_max_retries(self, max_retries: u32) -> Self
pub fn with_max_retries(self, max_retries: u32) -> Self
Set the maximum number of retries before failure