pub enum SessionMessage {
OnMessage {
message: ProtoMessage,
direction: MessageDirection,
ack_tx: Option<Sender<Result<(), SessionError>>>,
},
MessageError {
error: SessionError,
},
TimerTimeout {
message_id: u32,
message_type: ProtoSessionMessageType,
name: Option<Name>,
timeouts: u32,
},
TimerFailure {
message_id: u32,
message_type: ProtoSessionMessageType,
name: Option<Name>,
timeouts: u32,
},
ParticipantDisconnected {
name: Option<Name>,
},
StartDrain {
grace_period: Duration,
},
DeleteSession {
session_id: u32,
},
GetParticipantsList {
tx: Sender<Vec<Name>>,
},
}Expand description
Message types for communication between session components
Variants
OnMessage
application message coming from the app or from slim
MessageError
Error occurred during message processing
Fields

error: SessionErrorTimerTimeout
timeout signal for a message (ack,rtx or control messages) that needs to be send again
TimerFailure
timer failure, signal to the owner of the packet that the message will not be delivered
ParticipantDisconnected
sent by the controller sender when a disconnection is detected
StartDrain
message from session layer to the session controller to start to the close procedures of the session
DeleteSession
message from session controller to session layer to notify that the session can be removed safely
GetParticipantsList
Query the participants list from the handler