pub struct SubscriptionManager {
pub pending_acks: Arc<Mutex<HashMap<u64, Sender<Result<(), SubscriptionAckError>>>>>,
/* private fields */
}Fields
pending_acks: Arc<Mutex<HashMap<u64, Sender<Result<(), SubscriptionAckError>>>>>Implementations
Sourceimpl SubscriptionManager
impl SubscriptionManager
pub fn new(tx: SlimChannelSender) -> Self
Sourcepub fn register_ack(&self) -> (u64, Receiver<Result<(), SubscriptionAckError>>)
pub fn register_ack(&self) -> (u64, Receiver<Result<(), SubscriptionAckError>>)
Register a pending ACK entry and return the ack_id and receiver.
The caller is responsible for building and sending the message with this ack_id.
If sending fails, call cancel_ack to clean up.
Sourcepub fn register_ack_with_id(
&self,
id: u64,
) -> Receiver<Result<(), SubscriptionAckError>>
pub fn register_ack_with_id( &self, id: u64, ) -> Receiver<Result<(), SubscriptionAckError>>
Register a pending ACK entry under a caller-provided ID and return the receiver.
Sourcepub fn cancel_ack(&self, ack_id: u64)
pub fn cancel_ack(&self, ack_id: u64)
Remove a previously registered pending ACK (call on send failure).
Sourcepub async fn await_ack(
ack_rx: Receiver<Result<(), SubscriptionAckError>>,
) -> Result<(), SubscriptionAckError>
pub async fn await_ack( ack_rx: Receiver<Result<(), SubscriptionAckError>>, ) -> Result<(), SubscriptionAckError>
Await a previously registered ACK receiver, with a deadline of [ACK_TIMEOUT].
Uses futures_timer::Delay rather than tokio::time::timeout so that
this function works correctly outside a Tokio runtime with the time driver
enabled (e.g. when called from UniFFI async bindings).
Sourcepub fn resolve_ack(&self, ack: &ProtoSubscriptionAck)
pub fn resolve_ack(&self, ack: &ProtoSubscriptionAck)
Called by the App message loop to complete a waiting future for an ACK.